#
# spec file for package torbrowser-launcher
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           torbrowser-launcher
Version:        0.3.2
Release:        lp152.4.3.1
Summary:        Tool for launching and easy-updates of Tor Browser
License:        MIT
Group:          Productivity/Networking/Web/Utilities
URL:            https://github.com/micahflee/torbrowser-launcher
Source0:        https://github.com/micahflee/%{name}/archive/v%{version}.tar.gz
# From gh#micahflee/torbrowser_launcher#482 (SHA512: aea340451291ce5b0fd87fb2f399a57d1407c5f81ee2e01d389e5586eb9b83cf77e48bbdfe8a71043d834b2475a67f43fd0f398d788f3a41a7a007d77d29dcab)
Source1:        tor-browser-developers.asc
# PATCH-FEATURE-OPENSUSE pythontorbrowser-launcher-fix-distro-name.patch badshah400@gmail.com -- Use the correct distribution name (the setup.py code gives "SuSE" instead of "openSUSE")
Patch0:         torbrowser-launcher-fix-distro-name.patch
# PATCH-FIX-UPSTREAM torbrowser-launcher-apparmor-fixes.patch gh#micahflee/torbrowser-launcher#443 boo#1162284 badshah400@gmail.com -- Fix apparmor file so that it doesn't hinder actually running the browser, patch taken from upstream commits
Patch1:         torbrowser-launcher-apparmor-fixes.patch
# PATCH-FIX-UPSTREAM torbrowser-launcher-version-check-fix.patch gh#micahflee/torbrowser-launcher#499 badshah400@gmail.com -- Fix version checking with torbrowser 10.0+; patch taken from upstream PR (not yet merged)
Patch2:         torbrowser-launcher-version-check-fix.patch
BuildRequires:  apparmor-abstractions
BuildRequires:  gpg2
BuildRequires:  python3-PySocks
BuildRequires:  python3-devel
BuildRequires:  python3-gpg
BuildRequires:  python3-qt5
BuildRequires:  update-desktop-files
Requires:       gpg2
Requires:       python3-Parsley
Requires:       python3-PySocks
Requires:       python3-gpg
Requires:       python3-qt5
Requires:       python3-requests
Recommends:     %{name}-lang = %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
Tor Browser Launcher is intended to make Tor Browser easier to
install and use for GNU/Linux users. You install
torbrowser-launcher from your distribution's package manager and
it handles everything else:
  - Downloads and installs the most recent version of Tor Browser
    in your language and for your computer's architecture, or
    launches Tor Browser if it's already installed (Tor Browser
    will automatically update itself)
  - Certificate pins to https://www.torproject.org, so it doesn't
    rely on certificate authorities
  - Verifies Tor Browser's signature for you, to ensure the
    version you downloaded was cryptographically signed by Tor
    developers and was not tampered with
  - Adds "Tor Browser" and "Tor Browser Launcher Settings"
    application launcher to your desktop environment's menu
  - Apparmor profile to limit effect of Tor network compromise
  - Optionally plays a modem sound when you open Tor Browser
    (because Tor is so slow).

%package -n torbrowser-apparmor-profile
Summary:        Apparmor profile for Tor Browser
License:        BSD-3-Clause
Group:          Productivity/Security
Requires:       apparmor-utils

%description -n torbrowser-apparmor-profile
This package provides the apparmor profiles to safeguard against
a Tor network compromise.

%lang_package
%prep
%autosetup -p1
cp %{SOURCE1} share/torbrowser-launcher/

%build
python3 setup.py build

%install
python3 setup.py install --skip-build --root %{buildroot}

%suse_update_desktop_file %{buildroot}%{_datadir}/applications/torbrowser.desktop
%suse_update_desktop_file %{buildroot}%{_datadir}/applications/torbrowser-settings.desktop

%find_lang %{name} %{?no_lang_C}

# REMOVE USELESS TOPLEVEL .mo FILE
rm -fr %{buildroot}%{_datadir}/locale/%{name}.mo

%if 0%{?suse_version} < 1500
%post
%desktop_database_post

%postun
%desktop_database_postun
%endif

%files
%defattr(-,root,root)
%license LICENSE
%doc CHANGELOG.md README.md
%{_bindir}/%{name}
%{_datadir}/applications/*.desktop
%if 0%{?suse_version} <= 1315
%dir %{_datadir}/metainfo
%endif
%{_datadir}/metainfo/torbrowser.appdata.xml
%{_datadir}/pixmaps/torbrowser*.png
%{_datadir}/%{name}/
%{python3_sitelib}/torbrowser_launcher-%{version}-py%{py3_ver}.egg-info
%{python3_sitelib}/torbrowser_launcher/

%files -n torbrowser-apparmor-profile
%defattr(-,root,root)
%doc apparmor/license.txt
%config %{_sysconfdir}/apparmor.d/torbrowser.*
%config %{_sysconfdir}/apparmor.d/local/torbrowser.*
%config %{_sysconfdir}/apparmor.d/tunables/torbrowser

%files lang -f %{name}.lang

%changelog
* Wed Sep 23 2020 Atri Bhattacharya <badshah400@gmail.com>
- Add new key from upstream tor-browser as source and overwrite
  bundled key in tarball with this
  (gh#micahflee/torbrowser-launcher#481).
- Add torbrowser-launcher-version-check-fix.patch: Fix version
  checking with torbrowser 10.0+; patch taken from upstream PR
  (not yet merged) [gh#micahflee/torbrowser-launcher#499].
- Add further fixes to torbrowser-launcher-apparmor-fixes.patch
  to enable bundled libstdc++ to be mapped; fixes taken from
  pending upstream PR (gh#micahflee/torbrowser-launcher#503).
* Wed Mar 11 2020 Atri Bhattacharya <badshah400@gmail.com>
- Add torbrowser-launcher-apparmor-fixes.patch Fix apparmor file
  so that it doesn't hinder actually running the browser, patch
  taken from upstream commits
  (gh#micahflee/torbrowser-launcher#443, boo#1162284).
- Use %%autosetup to set up build directory.
* Fri Feb 28 2020 Atri Bhattacharya <badshah400@gmail.com>
- Switch Parsley and PySocks requires to python3 versions.
* Wed Jul 24 2019 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.3.2:
  * Switch to keys.openpgp.org when refreshing signing key,
    because SKS keyservers are broken
  * Use new Tor Browser logo
* Mon Feb 11 2019 Atri Bhattacharya <badshah400@gmail.com>
- Add Requires: python3-requests as application does not start
  without it (boo#1124868).
- Use %%%%license to install LICENSE file.
* Wed Nov  7 2018 badshah400@gmail.com
- Update to version 0.3.1:
  * Ship with latest version of the Tor Browser Developers
    OpenPGP public key.
  * Fix bug where TBL window stays open after Tor Browser is
    launched.
* Tue Sep 25 2018 badshah400@gmail.com
- Update to version 0.3.0:
  * Switched from python2 to python3.
  * Switched from gtk2 to Qt5.
  * Switched from twisted to requests/socks.
  * Use QThreads for async.
  * Removed modem sound.
  * Only refresh gpg keyring on verification error, instead of
    every time.
  * Updated AppArmor profiles.
  * Updated available languages, and fixed locale detection bug.
  * Fixed false signature verification error related to twisted.
- Update dependencies in keeping with upstream changes (noted
  above).
- Replace python(2) wherever used by the corresponding python3
  equivalent macro/command.
* Mon Feb  5 2018 badshah400@gmail.com
- Update to versio 0.2.9:
  * Fixed crash issue related to Tor Browser 7.5 changing how the
    currently installed version number is stored
  * Updated list of Tor Project dist mirrors
  * Fixed edge case crash for when stdout isn't writable
  * Updated AppStream metadata
  * Updated AppArmor profiles
- Only run post[un] scripts for openSUSE < 1500; these macros are
  void for newer versions, where rpm triggers automatically take
  care of the appropriate action.
* Sun Jul  2 2017 badshah400@gmail.com
- Update to version 0.2.8:
  * Update URL to check for latest version, which changed in Tor
    Browser 7.
  * Automatically refresh GPG keyring, to prevent signature
    verification false positives.
  * Improve GnuPG code by using GPGME if available.
  * Updated AppArmor profiles.
  * Added Czech, Hungarian localization.
* Mon Feb 13 2017 badshah400@gmail.com
- Update to version 0.2.7:
  * Updated Tor Browser signing key because they added a new
    subkey and verification was failing.
  * Updated AppArmor profiles.
  * Improved localization, and added Russian.
- Split out a %%{name}-lang package with all the non_C language
  translations; remove useless top-level
  %%{_datadir}/locale/%%{name}.mo file.
* Tue Feb  7 2017 badshah400@gmail.com
- Add Requires: python-Parsley to fix downloading through tor
  local server (boo#1023484).
* Sun Aug  7 2016 badshah400@gmail.com
- Update to version 0.2.6:
  + Fixed bug related to fallback to English feature that caused
    Settings to crash.
* Wed Jul 20 2016 badshah400@gmail.com
- Update to version 0.2.5:
  + Fix issue where Tor Browser Launcher failed to launch if
    currently installed version of Tor Browser was too old.
  + If Tor Browser download isn't available in your language,
    fallback to English.
  + Avoid re-downloading tarball if it's already present.
  + Verify GnuPG importing keys using status-fd rather than exit
    codes.
  + Various AppArmor improvements.
  + Remove unused dependency of IPolicyForHTTPS.
* Thu Mar 17 2016 badshah400@gmail.com
- Update to version 0.2.4:
  + Fix signature verification bypass attack.
- Changes from version 0.2.3:
  + Removed certificate pinning to https://www.torproject.org to
    avoid issues with upcoming certificate change, and hard-coded
    minimum Tor Browser version in the release.
  + Fix issue with detecting language.
  + Make Tor SOCKS5 proxy configurable, for users not running on
    9050.
  + Improved AppArmor profiles.
  + Added translations.
  + Switched from xpm icons to png icons.
  + Changed "Exit" button to "Cancel" button.
  + New package description.
* Fri Nov 27 2015 badshah400@gmail.com
- Initial package (rename of python-torbrowser-launcher).
- Patch torbrowser-launcher-fix-distro-name.patch added, fixes
  distro name used by application.
